@@ -143,6 +143,64 @@ class InfoObjectFilter(django_filters.FilterSet):
                   'identifier__namespace','identifier__uid','timestamp', 'create_timestamp','marking_thru__marking__identifier__uid']
 
 
+class CompleteInfoObjectFilter(django_filters.FilterSet):
+
+    # We want to restrict the selection of InfoObject Types to those for which there are actually
+    # objects in the system. The first try to do so was the query below, but that becomes awfully
+    # slow with many objects in the system, because for some reason, Django makes the sQL query
+    # such that it orders as the very first on *all* objects.
+
+    #iobject_type_qs = InfoObjectType.objects.annotate(num_objects=Count('iobject_set')). \
+    #    filter(num_objects__gt=0).prefetch_related('iobject_family').order_by('iobject_family__name','name')
+  
+
+    # The query below is a lot faster
+
+    iobject_type_qs_a = InfoObject.objects.values('iobject_type__id').distinct()
+    iobject_type_qs = InfoObjectType.objects.\
+                      filter(pk__in=iobject_type_qs_a.filter()).order_by('iobject_family__name','name').prefetch_related('iobject_family')
+
+
+    iobject_type =  django_filters.ModelChoiceFilter(queryset= iobject_type_qs,
+                                                    required=None,
+                                                    label="InfoObject Type",
+                                                    to_field_name='id')
+
+    iobject_type__iobject_family = django_filters.ModelChoiceFilter(
+        queryset= InfoObjectFamily.objects.all(),
+        required=None,
+        label="InfoObject Family",
+        to_field_name='id')
+
+    identifier__namespace = django_filters.ModelChoiceFilter(
+        queryset= IdentifierNameSpace.objects.all(),
+        required=None,
+        label="ID Namespace",
+        to_field_name='id')
+
+    name = django_filters.CharFilter(lookup_type='icontains',
+                                                label='Name contains')
+
+    iobject_type__name = django_filters.CharFilter(lookup_type='regex',
+                                                label='Object Type matches')
+
+    identifier__uid = django_filters.CharFilter(lookup_type='icontains',
+                                                label='ID contains')
+
+    marking_thru__marking__identifier__uid = django_filters.CharFilter(lookup_type='icontains',
+                                                                       label='Marking ID contains')
+
+    timestamp = ExtendedDateRangeFilter(label="Object Creation Timestamp")
+
+    create_timestamp = ExtendedDateRangeFilter(label="Import Timestamp")
+
+    class Meta:
+        order_by = create_order_keyword_list(['identifier__uid','timestamp','create_timestamp','name','iobject_type','iobject_type__iobject_family'])
+        model = InfoObject
+        fields = ['iobject_type','iobject_type__name','iobject_type__iobject_family','name',
+                  'identifier__namespace','identifier__uid','timestamp', 'create_timestamp','marking_thru__marking__identifier__uid']
+
+
 
 class IdSearchFilter(django_filters.FilterSet):
 
