@@ -30,6 +30,9 @@ urlpatterns = patterns('',
     url(r'^View/InfoObject/?$',
         views.InfoObjectList.as_view(),
         name="url.dingos.list.infoobject.generic"),
+    url(r'^View/InfoObject/All/?$',
+        views.InfoObjectListIncludingInternals.as_view(),
+        name="url.dingos.list.infoobject.all.generic"),
     url(r'^View/InfoObject/(?P<pk>\d*)/$',
         views.InfoObjectView.as_view(),
         name= "url.dingos.view.infoobject"),
